@@ -110,6 +110,7 @@ class FeedFoward(nn.Module):
         self.net = nn.Sequential(
             nn.Linear(embedding_size, linear_compressor),
             nn.ReLU(),
+            # nn.LeakyReLU(),
             nn.Linear(linear_compressor, embedding_size),
             nn.Dropout(dropout),
         )
@@ -127,8 +128,8 @@ class Block(nn.Module):
     :param sequence_len: the length of the input sequence
     :param dropout: the dropout rate
     :param num_heads: the number of attention heads
-    :param linear_compressor: the size of the linear layer in the feed-forward network, if None, use embedding_size*4
     :param causal: whether to use causal masking
+    :param linear_compressor: the size of the linear layer in the feed-forward network, if None, use embedding_size*4
     """
 
     def __init__(
@@ -137,8 +138,8 @@ class Block(nn.Module):
         sequence_len,
         dropout,
         num_heads,
-        linear_compressor,
         causal,
+        linear_compressor,
     ):
         # embedding_size: embedding dimension, num_heads: the number of heads we'd like
         super().__init__()
@@ -148,7 +149,11 @@ class Block(nn.Module):
         )
         if linear_compressor is None:
             linear_compressor = embedding_size * 4
-        self.ffwd = FeedFoward(embedding_size, linear_compressor, dropout)
+        self.ffwd = FeedFoward(
+            embedding_size=embedding_size,
+            linear_compressor=linear_compressor,
+            dropout=dropout,
+        )
         self.ln1 = nn.LayerNorm(embedding_size)
         self.ln2 = nn.LayerNorm(embedding_size)
 
@@ -195,16 +200,16 @@ class MultiHeadSelfAttention(nn.Module):
         self.position_embedding_table = nn.Embedding(sequence_len, embedding_size)
         if sigma_compressor is None:
             sigma_compressor = []
-        if dropout <= 1.0 or len(sigma_compressor) != num_layers:
+        if len(sigma_compressor) != num_layers:
             self.blocks = nn.Sequential(
                 *[
                     Block(
-                        embedding_size,
+                        embedding_size=embedding_size,
                         sequence_len=sequence_len,
                         dropout=dropout,
                         num_heads=num_heads,
-                        linear_compressor=embedding_size * 4,
                         causal=causal,
+                        linear_compressor=embedding_size * 4,
                     )
                     for _ in range(num_layers)
                 ]
@@ -218,8 +223,8 @@ class MultiHeadSelfAttention(nn.Module):
                         sequence_len=sequence_len,
                         dropout=dropout,
                         num_heads=num_heads,
-                        linear_compressor=sigma_compressor[i],
                         causal=causal,
+                        linear_compressor=sigma_compressor[i],
                     )
                 )
             self.blocks = nn.Sequential(*blks)
